==> apache-iceberg-0.13.1.tar.gz: apache-iceberg-0.13.1/core/src/main/java/org/apache/iceberg/actions/BaseRewriteManifestsActionResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iceberg.actions;

import org.apache.iceberg.ManifestFile;
import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;

public class BaseRewriteManifestsActionResult implements RewriteManifests.Result {

  private final Iterable<ManifestFile> rewrittenManifests;
  private final Iterable<ManifestFile> addedManifests;

  public BaseRewriteManifestsActionResult(Iterable<ManifestFile> rewrittenManifests,
                                          Iterable<ManifestFile> addedManifests) {
    this.rewrittenManifests = rewrittenManifests;
    this.addedManifests = addedManifests;
  }

  public static RewriteManifests.Result empty() {
    return new BaseRewriteManifestsActionResult(ImmutableList.of(), ImmutableList.of());
  }

  @Override
  public Iterable<ManifestFile> rewrittenManifests() {
    return rewrittenManifests;
  }

  @Override
  public Iterable<ManifestFile> addedManifests() {
    return addedManifests;
  }
}

==> apache-iceberg-1.2.1.tar.gz: apache-iceberg-1.2.1/core/src/main/java/org/apache/iceberg/actions/BaseRewriteManifestsActionResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg.actions;

import org.apache.iceberg.ManifestFile;
import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;

public class BaseRewriteManifestsActionResult implements RewriteManifests.Result {

  private final Iterable<ManifestFile> rewrittenManifests;
  private final Iterable<ManifestFile> addedManifests;

  public BaseRewriteManifestsActionResult(
      Iterable<ManifestFile> rewrittenManifests, Iterable<ManifestFile> addedManifests) {
    this.rewrittenManifests = rewrittenManifests;
    this.addedManifests = addedManifests;
  }

  public static RewriteManifests.Result empty() {
    return new BaseRewriteManifestsActionResult(ImmutableList.of(), ImmutableList.of());
  }

  @Override
  public Iterable<ManifestFile> rewrittenManifests() {
    return rewrittenManifests;
  }

  @Override
  public Iterable<ManifestFile> addedManifests() {
    return addedManifests;
  }
}
